@@ -214,9 +214,7 @@ class CloudFrontToS3Props:
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
         if cloud_front_distribution_props is not None:
-            self._values[
-                "cloud_front_distribution_props"
-            ] = cloud_front_distribution_props
+            self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
         if existing_bucket_obj is not None:
             self._values["existing_bucket_obj"] = existing_bucket_obj
         if insert_http_security_headers is not None:
